HurraySyncEventPayload

Struct HurraySyncEventPayload 

#[repr(C)]
pub struct HurraySyncEventPayload { pub sync_handle: *mut c_void, pub sync_handle_device_tag: u8, pub event_release_fn: HurrayEventReleaseFn, pub event_release_context: *mut c_void, }
Payload for the Event sync mode handoff.

The consumer supplies this struct when calling hurray_buffer_handoff_event to provide the device event that the producer recorded and on which the consumer will wait.

Fields

sync_handle: *mut c_void

Non-null device-event handle (e.g., cudaEvent_t).

sync_handle_device_tag: u8

Wire byte of the device on which sync_handle was recorded.

event_release_fn: HurrayEventReleaseFn

Release callback for sync_handle; MUST be non-null.

event_release_context: *mut c_void

Opaque context forwarded to event_release_fn; MAY be null.