pub(crate) fn append_data_rows(
rows: &mut Vec<Row>,
desc: &TensorDescriptor,
buf: &[u8],
buf_file_offset: usize,
mode: DataMode,
)Expand description
Append rows displaying the tensor buffer buf in the chosen DataMode.
buf_file_offset is the byte offset of buf within the file — used for
the offset column in hex-mode rows.